@@ -11,7 +11,7 @@ scripts = root_path + "/../scripts"
 from config import commands
 
 
-def launch() -> None:
+def main() -> None:
     if "--wrapper" in sys.argv:
         run(
             "alacritty --class=Alacritty,Pycher -e "
@@ -36,4 +36,4 @@ def launch() -> None:
 
 
 if __name__ == "__main__":
-    launch()
+    main()
